﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;
using System.Data.SqlClient;
namespace DAL
{
    class DbHelperSQL
    {
        public static string connectionString = System.Configuration.ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();//数据库连接语句
        private static void PrepareCommand(SqlCommand cmd, SqlConnection comm, SqlTransaction trans, string cmdText, SqlParameter[] cmdParms)
        {
            if (comm.State != ConnectionState.Open)//如果连接状态不是打开的，那么打开连接
                comm.Open();
            cmd.Connection = comm;//指定SplCommand类的连接对象
            cmd.CommandText = cmdText;//指定SplCommand类要执行的SQL语句或存储过程
            if (trans != null)
                cmd.Transaction = trans;//指定SplCommand类的的事务
            cmd.CommandType = CommandType.Text;//指定类型
            if (cmdParms != null)//如果传入的SqlParameter不为空，那么foreach循环遍历加入到SqlCommand类的参数属性中
            {
                foreach (SqlParameter parametet in cmdParms)
                {
                    if ((parametet.Direction == ParameterDirection.InputOutput || parametet.Direction == ParameterDirection.Input) && (parametet.Value == null))
                    {
                        parametet.Value = DBNull.Value;
                    }
                    cmd.Parameters.Add(parametet);
                }


            }
        }
        public static int ExecuteSql(string SQLString, params SqlParameter[] cmdParms)
        {
            using (SqlConnection connection = new SqlConnection(connectionString))//建立一个数据库连接对象 connection 
            {
                using (SqlCommand cmd = new SqlCommand())//对数据库执行的一个SQL 语句或存储过程
                {
                    try
                    {
                        PrepareCommand(cmd, connection, null, SQLString, cmdParms);//执行PrepareCommand
                        int rows = cmd.ExecuteNonQuery();//影响的行数
                        cmd.Parameters.Clear();
                        return rows;//返回rows
                    }
                    catch (System.Data.SqlClient.SqlException e)
                    {
                        throw e;
                    }
                }
            }
        }
        public static SqlDataReader ExecuteReader(string SQLString, params SqlParameter[] cmdParms)
        {
            SqlConnection connection = new SqlConnection(connectionString);//建立一个数据库连接对象 connection 
            SqlCommand cmd = new SqlCommand();//对数据库执行的一个SQL 语句或存储过程

            try
            {
                PrepareCommand(cmd, connection, null, SQLString, cmdParms);//执行PrepareCommand
                SqlDataReader myReader = cmd.ExecuteReader(CommandBehavior.CloseConnection);//执行查询
                cmd.Parameters.Clear();
                return myReader;//返回myReader
            }
            catch (System.Data.SqlClient.SqlException e)
            {
                throw e;
            }

        }
        public static object GetSingle(string SQLString, params SqlParameter[] cmdParms)
        {
            using (SqlConnection connection = new SqlConnection(connectionString))//建立一个数据库连接对象 connection 
            {
                using (SqlCommand cmd = new SqlCommand())//对数据库执行的一个SQL 语句或存储过程
                {
                    try
                    {
                        PrepareCommand(cmd, connection, null, SQLString, cmdParms);//执行PrepareCommand
                        object odj = cmd.ExecuteScalar();
                        cmd.Parameters.Clear();
                        if ((Object.Equals(odj, null)) || (Object.Equals(odj, System.DBNull.Value)))
                        {
                            return null;
                        }
                        else
                        {
                            return odj;
                        }
                    }
                    catch (System.Data.SqlClient.SqlException e)
                    {
                        throw e;
                    }
                }

            }

        }
        public static DataSet Query(string SQLString, params SqlParameter[] cmdParms)
        {
            using (SqlConnection connection = new SqlConnection(connectionString))//建立一个数据库连接对象 connection 
            {
                SqlCommand cmd = new SqlCommand();//对数据库执行的一个SQL 语句或存储过程
                PrepareCommand(cmd, connection, null, SQLString, cmdParms);//执行PrepareCommand
                using (SqlDataAdapter da = new SqlDataAdapter(cmd))//数据适配器
                {
                    DataSet ds = new DataSet(); //调用了默认构造函数，对象已经初始化，分配了内存空间 
                    try
                    {
                        da.Fill(ds, "ds"); //通过适配器对象的Fill方法将数据填充到数据集中
                        cmd.Parameters.Clear();
                    }
                    catch (System.Data.SqlClient.SqlException ex)
                    {
                        throw new Exception(ex.Message);
                    }
                    return ds;
                }
            }
        }
    }
}

